@@ -23,24 +23,29 @@ async def reload(bat, dir, client):
 class admin():
     async def mute(ctx, member, *args, role_add=1, role_remove=1, reason=None, **kwargs):
         if ctx.guild.get_role(role_add) in member.roles:
-            await ctx.send(f"{member.mention} is already muted.", delete_after=5)
+            embed = discord.Embed(color = 0xD40C00, description = f"{member.name}#{member.discriminator} is already muted.")
+            await ctx.send(embed=embed, delete_after=5)
         else:
             await member.add_roles(ctx.guild.get_role(role_add))
             if role_remove != 1:
                 await member.remove_roles(ctx.guild.get_role(role_remove))
             if reason == None:
-                await ctx.send(f"{member.mention} has been muted.", delete_after=7)
+                embed = discord.Embed(color = 0x32c12c, description = f"Muted {member.name}#{member.discriminator}.")
+                await ctx.send(embed=embed, delete_after=7)
             else:
-                await ctx.send(f"{member.mention} has been muted. \nReason: {reason}", delete_after=7)
+                embed = discord.Embed(color = 0x32c12c, description = f"Muted {member.name}#{member.discriminator}. Reason: {reason}")
+                await ctx.send(embed=embed, delete_after=7)
 
     async def unmute(ctx, member, *args, role_add=1, role_remove=1, **kwargs):
         if ctx.guild.get_role(role_remove) not in member.roles:
-            await ctx.send(f"{member.mention} is not muted.", delete_after=7)
+            embed = discord.Embed(color = 0xD40C00, description = f"{member.name}#{member.discriminator} is not muted.")
+            await ctx.send(embed=embed, delete_after=5)
         else:
             await member.remove_roles(ctx.guild.get_role(role_remove))
             if role_add != 1:
                 await member.add_roles(ctx.guild.get_role(role_add))
-            await ctx.send(f"{member.mention} is now unmuted.", delete_after=7)
+            embed = discord.Embed(color = 0x32c12c, description = f"Unmuted {member.name}#{member.discriminator}.")
+            await ctx.send(embed=embed, delete_after=7)
 
     async def clear(ctx, amount=None):
         if amount == None:
@@ -51,16 +56,37 @@ class admin():
         await ctx.message.delete()
         purged = await ctx.channel.purge(limit=amount ,after=limit)
         purged = len(purged)
-        await ctx.send(f'cleared {purged} messages', delete_after=5)
+        embed = discord.Embed(color = 0x32c12c, description = f"Cleared {purged} messages.")
+        await ctx.send(embed=embed, delete_after=5)
         return purged
 
     async def kick(ctx, member, reason=None):
         await member.kick(reason=reason)
-        await ctx.send(f'Kicked {member.mention} Reason: {reason}', delete_after=7)
+        if reason is None:
+            embed = discord.Embed(color = 0x32c12c, description = f"Kicked {member.name}#{member.discriminator}.")
+            await ctx.send(embed=embed, delete_after=7)
+        else:
+            embed = discord.Embed(color = 0x32c12c, description = f"Kicked {member.name}#{member.discriminator}. Reason: {reason}")
+            await ctx.send(embed=embed, delete_after=7)
 
     async def ban(ctx, member, reason=None):
         await member.ban(reason=reason)
-        await ctx.send(f'Banned {member.mention} Reason: {reason}', delete_after=7)
+        if reason is None:
+            embed = discord.Embed(color = 0x32c12c, description = f"Banned {member.name}#{member.discriminator}.")
+            await ctx.send(embed=embed, delete_after=7)
+        else:
+            embed = discord.Embed(color = 0x32c12c, description = f"Banned {member.name}#{member.discriminator}. Reason: {reason}")
+            await ctx.send(embed=embed, delete_after=7)
+
+    async def softban(ctx, member, reason=None):
+        await member.ban(reason=reason)
+        if reason is None:
+            embed = discord.Embed(color = 0x32c12c, description = f"Soft banned {member.name}#{member.discriminator}.")
+            await ctx.send(embed=embed, delete_after=7)
+        else:
+            embed = discord.Embed(color = 0x32c12c, description = f"Soft banned {member.name}#{member.discriminator}. Reason: {reason}")
+            await ctx.send(embed=embed, delete_after=7)
+        await member.unban()
 
     async def unban(ctx, member):
         banned_users = await ctx.guild.bans()
@@ -68,12 +94,12 @@ class admin():
         for ban_entry in banned_users: 
             user = ban_entry.user
             if (user.name, user.discriminator) == (member_name, member_discriminator):
-                await ctx.message.delete()
                 await ctx.guild.unban(user)
-                await ctx.send(f'Unbanned {user.name}#{user.discriminator}', delete_after=7)
+                embed = discord.Embed(color = 0xD40C00, description = f"Unbanned {member.name}#{member.discriminator}.")
+                await ctx.send(embed=embed, delete_after=7)
             else:
-                await ctx.message.delete()
-                await ctx.send(f"{member} is not banned.", delete_after=5)
+                embed = discord.Embed(color = 0xD40C00, description = f"{member.name}#{member.discriminator} is not banned.")
+                await ctx.send(embed=embed, delete_after=5)
 class curse():
     async def add_banned_word(ctx, word, dir):
         arg = word
@@ -97,17 +123,21 @@ class curse():
                             msg = f"One of those words are already in the list."
                         else:
                             msg = f"That word is already in the list."
-                        await ctx.send(msg, delete_after=5)
+                        embed = discord.Embed(color = 0xD40C00, description = msg)
+                        await ctx.send(embed=embed, delete_after=5)
                         return
             word = word.replace(" ", "")
             word = word.split(",")
             for x in word:
                 if word.count(x) > 1:
-                    await ctx.send("Words cannot be added twice.", delete_after=5)
+                    embed = discord.Embed(color = 0xD40C00, description = "Words cannot be added twice.")
+                    await ctx.send(embed=embed, delete_after=5)
                     return
                 await db.execute("INSERT INTO curses (curse,guild) VALUES (?,?)", (x,guildid))
             await db.commit()
         await db.close()
+        embed = discord.Embed(color = 0x32c12c, description = "Added to the list.")
+        await ctx.send(embed=embed, delete_after=7)
     async def remove_banned_word(ctx, word, dir):
             db = await aiosqlite.connect("curse.db")
             guildid = str(ctx.guild.id)
@@ -125,16 +155,21 @@ class curse():
                                 in_db = True
                 if in_db == False:
                     if len(word) > 1:
-                        await ctx.send("None of those words are in the list", delete_after=5)
+                        embed = discord.Embed(color = 0xD40C00, description = "None of those words are in the list")
+                        await ctx.send(embed=embed, delete_after=5)
                     else:
-                        await ctx.send("This word is not in the list", delete_after=5)
+                        embed = discord.Embed(color = 0xD40C00, description = "That word is not in the list.")
+                        await ctx.send(embed=embed, delete_after=5)
                     return 
                 for x in word:
                     await db.execute("DELETE FROM curses WHERE curse = ? and guild = ?", (x,guildid))
                     await db.commit()
                 await db.close()
+                embed = discord.Embed(color = 0x32c12c, description = "Removed from the list.")
+                await ctx.send(embed=embed, delete_after=5)
             except:
-                await ctx.send("This word is not in the list or a list was never created", delete_after=5)
+                embed = discord.Embed(color = 0xD40C00, description = "A list has not been created yet.")
+                await ctx.send(embed=embed, delete_after=5)
                 await db.close()
     async def message_filter(message, dir, admin: int=1):
         if message.author.bot or message.guild is None:
@@ -310,7 +345,12 @@ class warnings():
         await db.execute("INSERT INTO warnings (member_id,guild,reason) VALUES (?,?,?)", (member,guildid,reason))
         await db.commit()
         await db.close()
-        await ctx.send(f"{user.mention} has been warned. \nReason: {reason}", delete_after=7)
+        if reason == None:
+            embed = discord.Embed(color = 0x32c12c, description = f"Warned {user.name}#{user.discriminator}.")
+            await ctx.send(embed=embed, delete_after=7)
+        else:
+            embed = discord.Embed(color = 0x32c12c, description = f"Warned {user.name}#{user.discriminator}. Reason: {reason}")
+            await ctx.send(embed=embed, delete_after=7)
     async def warnings_list(ctx, member, dir):
             os.chdir(dir)
             guildid = str(ctx.guild.id)
@@ -328,10 +368,12 @@ class warnings():
                         embed.set_footer(text=f"Total Warnings | {number}")
                         await ctx.send(embed=embed, reference= ctx.message.reference or ctx.message)
                     else:
-                        await ctx.send(f"{user.mention} has no warnings", reference= ctx.message.reference or ctx.message)
+                        embed = discord.Embed(color = 0xD40C00, description = f"{user.name}#{user.discriminator} has no warnings.")
+                        await ctx.send(embed=embed, delete_after=5)
                 await db.close()
             except:
-                await ctx.send(f"{user.mention} has no warnings", reference= ctx.message.reference or ctx.message)
+                embed = discord.Embed(color = 0xD40C00, description = f"{user.name}#{user.discriminator} has no warnings.")
+                await ctx.send(embed=embed, delete_after=5)
                 await db.close()
     async def unwarn(ctx, member, dir, number):
         os.chdir(dir)
@@ -346,13 +388,15 @@ class warnings():
             async for entry in cursor:
                 count += 1
         if count < 1:
-            await ctx.send(f"{user.mention} has no warnings.", delete_after=5)
+            embed = discord.Embed(color = 0xD40C00, description = f"{user.name}#{user.discriminator} has no warnings.")
+            await ctx.send(embed=embed, delete_after=5)
             return
         if number == "all":
             await db.execute("DELETE FROM warnings WHERE guild = ? and member_id = ?", (guild,member))
             await db.commit()
             await db.close()
-            await ctx.send(f"Cleared all warnings from {user.mention}", delete_after=7)
+            embed = discord.Embed(color = 0x32c12c, description = f"Cleared all warnings from {user.name}#{user.discriminator}.")
+            await ctx.send(embed=embed, delete_after=7)
             return
         else:
                 try:
@@ -374,6 +418,8 @@ class warnings():
                         number_list = list(map(str, number_list))
                         number_list = ", ".join(number_list)
                         await ctx.send(f"Cleared warnings {number_list} from {user.mention}.", delete_after=7)
+                        embed = discord.Embed(color = 0x32c12c, description = f"Cleared warnings {number_list} from .{user.name}#{user.discriminator}.")
+                        await ctx.send(embed=embed, delete_after=7)
                     else:
                         number = int(number)
                         dict = {}
@@ -385,12 +431,15 @@ class warnings():
                         await db.execute("DELETE FROM warnings WHERE id = ?", (dict[str(number)],))
                         await db.commit()
                         await db.close()
-                        await ctx.send(f"Cleared {user.mention}'s #{number} warning.", delete_after=7)
+                        embed = discord.Embed(color = 0x32c12c, description = f"Cleared {user.name}#{user.discriminator}'s' #{number} warning.")
+                        await ctx.send(embed=embed, delete_after=7)
                 except:
                     if number == "all":
-                        await ctx.send(f"{user.mention} has no warnings.", delete_after=5)
+                        embed = discord.Embed(color = 0xD40C00, description = f"{user.name}#{user.discriminator} has no warnings.")
+                        await ctx.send(embed=embed, delete_after=5)
                     else:
-                        await ctx.send(f"{user.mention} does not have that many warnings.", delete_after=5)
+                        embed = discord.Embed(color = 0xD40C00, description = f"{user.name}#{user.discriminator} does not have that many warnings.")
+                        await ctx.send(embed=embed, delete_after=5)
     async def punish(ctx, member, dir, *args, one=None, two=None, three=None, four=None, five=None, six=None, seven=None, eight=None, nine=None, ten=None, eleven=None, twelve=None, thirteen=None, fourteen=None, fifteen=None, remove_role=None, add_role=None, **kwargs):
                     os.chdir(dir)
                     memberid = str(member.id)
@@ -600,7 +649,8 @@ class rr():
             for x in emoji_list:
                 role = role_list[number]
                 if "@" not in role:
-                    await ctx.send("Invalid Role. Please read https://sites.google.com/view/dpys/reaction-roles", delete_after=15)
+                    embed = discord.Embed(color = 0xD40C00, description = "Invalid Role. Please read https://sites.google.com/view/dpys/reaction-roles")
+                    await ctx.send(embed=embed, delete_after=15)
                     return
                 role = role.replace("<", "")
                 role = role.replace(">", "")
@@ -614,7 +664,8 @@ class rr():
         else:
             await msg.add_reaction(emoji)
             if "@" not in role:
-                await ctx.send("Invalid Role. Please read https://sites.google.com/view/dpys/reaction-roles", delete_after=15)
+                embed = discord.Embed(color = 0xD40C00, description = "Invalid Role. Please read https://sites.google.com/view/dpys/reaction-roles")
+                await ctx.send(embed=embed, delete_after=15)
                 return
             role = role.replace("<", "")
             role = role.replace(">", "")
@@ -660,7 +711,9 @@ class rr():
         await db.execute("DELETE FROM rr WHERE guild = ?", (guild,))
         await db.commit()
         await db.close()
-        await ctx.send("Delted all reaction role info for this server.", delete_after=7)
+        embed = discord.Embed(color = 0x32c12c, description = "Deleted all reaction role info for this server.")
+        await ctx.send(embed=embed, delete_after=7)
+        
 
     async def clear_one(ctx, dir, message_id):
         os.chdir(dir)
@@ -674,7 +727,8 @@ class rr():
         await db.commit()
         await db.close()
         message_id = ", ".join(message_id)
-        await ctx.send(f"Delted reaction role info for {message_id}", delete_after=7)
+        embed = discord.Embed(color = 0x32c12c, description = f"Delted reaction role info for {message_id}")
+        await ctx.send(embed=embed, delete_after=7)
 
     async def clear_rr(message, dir):
         os.chdir(dir)
@@ -728,8 +782,10 @@ class rr():
                 embed.set_footer(text=f"Total Reaction Roles | {number}")
             else:
                 embed.set_footer(text=f"Total Reaction Roles | {number}")
-                await ctx.reply("One of your reaction roles went over the Discord limit. It will still work perfectly but only essential data will be displayed in this command to save space.", delete_after=10)
+                limit_embed = discord.Embed(color = 0xD40C00, description = "One of your reaction roles went over the Discord limit. It will still work perfectly but only essential data will be displayed in this command to save space.")
+                await ctx.reply(embed=limit_embed, delete_after=7)
             await ctx.send(embed=embed, reference= ctx.message.reference or ctx.message)
         else:
-            await ctx.send("There are no reaction roles in this server.", delete_after=5)
+            embed = discord.Embed(color = 0xD40C00, description = "There are no reaction roles in this server.")
+            await ctx.send(embed=embed, delete_after=5)
         await db.close()
